#include <gnome-db.h>

int main (int argc, char *argv[])
{
  GtkWidget* window;
  GtkWidget* log_viewer;

  gnome_db_init("test-log-viewer", "1.0", argc, argv);

  window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  log_viewer = gnome_db_log_viewer_new();
  gtk_container_add(GTK_CONTAINER(window), log_viewer);
  gtk_widget_show_all(window);
  gnome_db_log_viewer_load_file(GNOME_DB_LOG_VIEWER(log_viewer), "OAFIID:gda-postgres:b04e9dc2-1cc8-4027-8cf9-27dcb6a2a63f");
  gnome_db_main(NULL);
  return 0;
}
